@@ -2,7 +2,7 @@
 
 """
 tcp:
-    传输的数据包格式:raw_data\r\n
+    传输的数据包格式:raw_data\n
 udp:
     传输的数据包格式:raw_data
     因为并不通过末尾的符号做识别
